@@ -8,6 +8,7 @@ var istanbul = require('gulp-istanbul');
 var nsp = require('gulp-nsp');
 var plumber = require('gulp-plumber');
 var coveralls = require('gulp-coveralls');
+var codacy = require('gulp-codacy');
 
 gulp.task('static', function () {
   return gulp.src('**/*.js')
@@ -55,7 +56,8 @@ gulp.task('coveralls', ['test'], function () {
   }
 
   return gulp.src(path.join(__dirname, 'coverage/lcov.info'))
-    .pipe(coveralls());
+    .pipe(coveralls())
+    .pipe(codacy());
 });
 
 gulp.task('prepublish', ['nsp']);
