@@ -1,5 +1,5 @@
 'use strict';
-var rx = require('rx');
+var rx = require('rx-lite-aggregates');
 
 function normalizeKeypressEvents(value, key) {
   return {value: value, key: key || {}};
